<?php
/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
return array(
    'year' => ':count жыл',
    'y' => ':count жыл',
    'month' => ':count ай',
    'm' => ':count ай',
    'week' => ':count апта',
    'w' => ':count апта',
    'day' => ':count күн',
    'd' => ':count күн',
    'hour' => ':count сағат',
    'h' => ':count сағат',
    'minute' => ':count минут',
    'min' => ':count минут',
    'second' => ':count секунд',
    's' => ':count секунд',
    'ago' => ':time бұрын',
    'from_now' => ':time кейін',
    'after' => ':time кейін',
    'before' => ':time бұрын',
);
