<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count 년',
    'y' => ':count 년',
    'month' => ':count 개월',
    'm' => ':count 개월',
    'week' => ':count 주일',
    'w' => ':count 주일',
    'day' => ':count 일',
    'd' => ':count 일',
    'hour' => ':count 시간',
    'h' => ':count 시간',
    'minute' => ':count 분',
    'min' => ':count 분',
    'second' => ':count 초',
    's' => ':count 초',
    'ago' => ':time 전',
    'from_now' => ':time 후',
    'after' => ':time 이후',
    'before' => ':time 이전',
);
