<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count سال',
    'month' => ':count ماه',
    'week' => ':count ہفتے',
    'day' => ':count روز',
    'hour' => ':count گھنٹے',
    'minute' => ':count منٹ',
    'second' => ':count سیکنڈ',
    'ago' => ':time پہلے',
    'from_now' => ':time بعد',
    'after' => ':time بعد',
    'before' => ':time پہلے',
);
